@@ -118,7 +118,8 @@ class TextEditWidget(QTextEdit, Widget):
     def __init__(self, field):
         Widget.__init__(self, field)
         QTextEdit.__init__(self)
-        self.setSizePolicy(QSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding))
+        self.setMinimumHeight(30)
+        self.setMaximumHeight(1000)
 
     def getData(self):
         return unicode(self.toPlainText())
